<?php
/**
 * @brief ImgWidthAndHeightAdder, a plugin for Dotclear 2
 *
 * @package Dotclear
 * @subpackage Plugins
 *
 * @author Julien Mudry and contributors
 *
 * @copyright Julien Mudry
 * @copyright GPL-2.0 https://www.gnu.org/licenses/gpl-2.0.html
 */
class imgWidthHeightAdder
{
    protected static $post_imgs     = [];
    protected static $post_imgs_reg = '#(?:<img[^>]+src="(.+?)".*?>)#msu';

    public static function updatePostEntries($ref)
    {
        if (@is_array($ref)) {
            /* Add image sizes for excerpt (HTML) */
            if (isset($ref['excerpt_xhtml'])) {
                if ($excerpt = &$ref['excerpt_xhtml']) {
                    // Find every image
                    if (preg_match_all(self::$post_imgs_reg, $excerpt, $m) > 0) {
                        foreach ($m[1] as $v) {
                            self::$post_imgs[$v] = [
                                'w' => null,
                                'h' => null,
                            ];
                        }

                        // Lookup the size for each image found
                        $media = new iwahaMedia();
                        $media->getMediaItems(self::$post_imgs);

                        // Add size information to every img tag
                        $excerpt = preg_replace_callback(self::$post_imgs_reg, [self::class, 'photoSize'], $excerpt);
                    }
                }
            }

            /* Add image sizes for content (HTML) */
            if (isset($ref['content_xhtml'])) {
                if ($content = &$ref['content_xhtml']) {
                    // Find every image
                    if (preg_match_all(self::$post_imgs_reg, $content, $m) > 0) {
                        foreach ($m[1] as $v) {
                            self::$post_imgs[$v] = [
                                'w' => null,
                                'h' => null,
                            ];
                        }

                        // Lookup the size for each image found
                        $media = new iwahaMedia();
                        $media->getMediaItems(self::$post_imgs);

                        // Add size information to every img tag
                        $content = preg_replace_callback(self::$post_imgs_reg, [self::class, 'photoSize'], $content);
                    }
                }
            }
        }
    }

    protected static function photoSize($match)
    {
        if (!self::$post_imgs[$match[1]]['w']) {
            return $match[0];
        }

        if (strpos($match[0], 'width=') !== false || strpos($match[0], 'height=') !== false) {
            return $match[0];
        }

        $img    = self::$post_imgs[$match[1]];
        $width  = $img['w'];
        $height = $img['h'];

        return preg_replace('#(<img[^>]+src="[^"]+?".*?)/>#msu', '$1' . ' height="' . $height . '" width="' . $width . '" />', $match[0]);
    }
}
